# Superdesk Core library [![Build Status](https://github.com/superdesk/superdesk-core/workflows/CI/badge.svg)](https://github.com/superdesk/superdesk-core/actions) [![Documentation Status](https://readthedocs.org/projects/superdesk/badge/?version=latest)](https://superdesk.readthedocs.io/en/latest/?badge=latest)

Utilities for building Superdesk applications.

### Installation

For installation instructions, please refer to the README file at: [https://github.com/superdesk/superdesk/](https://github.com/superdesk/superdesk/ "")

### Translations

#### Extracting messages

You can run `python setup.py extract_messages` to update `server.pot` file and commit changes to github.
Transifex will automatically fetch it and update the source.
